# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution	
#    Copyright (C) 2004-2009 Tiny SPRL (<http://tiny.be>). All Rights Reserved
#    $Id$
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from osv import osv, fields

class notafiscal(osv.osv):

    def _get_type(self, cr, uid, context=None):
        if context is None:
            context = {}
        type = context.get('type', 'O')
        return type

    def _get_reference_type(self, cr, uid, context=None):
        return [('none', _('Free Reference'))]

    def _get_currency(self, cr, uid, context):
#        user = pooler.get_pool(cr.dbname).get('res.users').browse(cr, uid, [uid])[0]
#        if user.company_id:
#            return user.company_id.currency_id.id
#        else:
#            return pooler.get_pool(cr.dbname).get('res.currency').search(cr, uid, [('rate','=',1.0)])[0]

    _name = 'l10n_br_nf.notafiscal'

    _columns = {
        'name': fields.char('Description', size=64, select=True,readonly=True, states={'draft':[('readonly',False)]}),
        'origin': fields.char('Origin', size=64, help="Reference of the document that produced this Nota Fiscal."),
        'company_id': fields.many2one('res.company', 'Company', required=True, change_default=True),
        'partner_id': fields.many2one('res.partner', 'Partner', change_default=True, readonly=True, required=True, states={'draft':[('readonly',False)]}),
        'partner_address_id': fields.many2one('res.partner.address', 'Contact Address', readonly=True, states={'draft':[('readonly',False)]}),
        'type': fields.selection([
            ('I','Inbound'),
            ('O','Outbound'),
            ],'Direction', readonly=True, select=True),
        'number': fields.char('Nota Fiscal Number', size=32, readonly=True, help="Unique number of the Nota Fiscal, computed automatically when the Nota Fiscal is created."),
        'reference': fields.char('Invoice Reference', size=64, help="The partner reference of this invoice."),
        'reference_type': fields.selection(_get_reference_type, 'Reference Type', required=True),
        'state': fields.selection([
            ('draft','Draft'),
            ('waiting', 'Waiting'),
            ('aproved','Aproved'),
            ('cancel','Cancelled')
        ],'State', select=True, readonly=True),
         'currency_id': fields.many2one('res.currency', 'Currency', required=True, readonly=True, states={'draft':[('readonly',False)]}),
        'payment_term': fields.many2one('account.payment.term', 'Payment Term',readonly=True, states={'draft':[('readonly',False)]},
            help="If you use payment terms, the due date will be computed automatically at the generation "\
                 "of accounting entries. If you keep the payment term and the due date empty, it means direct payment. "\
                "The payment term may compute several due dates, for example 50% now, 50% in one month."),
        'period_id': fields.many2one('account.period', 'Force Period', domain=[('state','<>','done')], help="Keep empty to use the period of the validation(invoice) date.", readonly=True, states={'draft':[('readonly',False)]}),             
        'fiscal_position': fields.many2one('account.fiscal.position', 'Fiscal Position')
    }

    _defaults = {
        'type': _get_type,
        'state': lambda *a: 'draft',
        'currency_id': _get_currency,
    }
    

notafiscal()
# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
